<?php

/**
* Copyright © 2016 Filoblu S.r.l. All rights reserved.
 */
 
namespace FiloBlu\Esb\Plugin\PrintDocument;
use \Magento\Sales\Api\Data\OrderInterface;
use \FiloBlu\Esb\Helper\Data;


/**
* Plugin that adds Print Document button.
 */

class Plugin{
	
    /**
     * @var \Magento\Framework\View\Element\AbstractBlock
     */  
	protected $_context;

    /**
     * @var \Magento\Sales\Api\OrderRepositoryInterface
     */  
	protected $_orderRepository;
	
	/**
     * @var \Magento\Framework\App\Config\ScopeConfigInterface
     */  
	protected $_scopeConfig;

    /**
     * @param \Magento\Sales\Api\OrderRepositoryInterface $orderRepository
	 * @param \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
     */  
	public function __construct(
	        \Magento\Sales\Api\OrderRepositoryInterface $orderRepository,
			\Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
	    ){
		$this->_orderRepository=$orderRepository;
		$this->_scopeConfig=$scopeConfig;
	}
	
    /**
     * Add Print Document Button
     *
     * @param \Magento\Backend\Block\Widget\Button\Toolbar $subject
     * @param \Magento\Framework\View\Element\AbstractBlock $context
     * @param \Magento\Backend\Block\Widget\Button\ButtonList $buttonList
     * @return void
     */
	public function beforePushButtons(
	        \Magento\Backend\Block\Widget\Button\Toolbar $subject,
	        \Magento\Framework\View\Element\AbstractBlock $context,
	        \Magento\Backend\Block\Widget\Button\ButtonList $buttonList
	    )
	    {
		$this->_context = $context;
		if ($context instanceof \Magento\Sales\Block\Adminhtml\Order\View) {
			$order=$this->_orderRepository->get($this->_context->getRequest()->getParam('order_id'));
			$invoices=$order->getInvoiceCollection();
			$shipping_country=$order->getShippingAddress()->getCountryId();
			$enabled_countries=explode(",", $this->_scopeConfig->getValue(
				'esb/print_documents/enabled_countries', 
				\Magento\Store\Model\ScopeInterface::SCOPE_STORE
			));
			if(count($invoices) > 0 && in_array($shipping_country, $enabled_countries)){
                $invoice_id=$invoices->getFirstItem()->getId();
				$buttonList->add(
				                    'print_documents',
				                    [
				                        'label' => __('Print Documents'),
				                        'class' => 'primary',
				                        'onclick' => 'setLocation("' . $this->_context->getUrl('esb/externalInvoice/print', ['invoice_id' => $invoice_id, 'redirect_path'=> 'order']) . '")',
				                    ]
				                );
			}
		}

	}
}
